// Use if you want to force the software SPI subsystem to be used for some reason (generally, you don't)
// #define FASTLED_FORCE_SOFTWARE_SPI
// Use if you want to force non-accelerated pin access (hint: you really don't, it breaks lots of things)
// #define FASTLED_FORCE_SOFTWARE_SPI
// #define FASTLED_FORCE_SOFTWARE_PINS
#include <FastLED.h>

///////////////////////////////////////////////////////////////////////////////////////////
//
// Move a white dot along the strip of leds.  This program simply shows how to configure the leds,
// and then how to turn a single pixel white and then off, moving down the line of pixels.
// 

// How many leds are in the strip?
#define NUM_LEDS 300

// For led chips like WS2812, which have a data line, ground, and power, you just
// need to define DATA_PIN.  For led chipsets that are SPI based (four wires - data, clock,
// ground, and power), like the LPD8806 define both DATA_PIN and CLOCK_PIN
// Clock pin only needed for SPI based chipsets when not using hardware SPI
#define DATA_PIN 5

// This is an array of leds.  One item for each led in your strip.
CRGB leds[NUM_LEDS];
int colorButton = 0;
CRGBPalette16 currentPalette;
TBlendType    currentBlending;

// This function sets up the ledsand tells the controller about them
void setup() {
	// sanity check delay - allows reprogramming if accidently blowing power w/leds
   	
   	Serial.begin(9600);
   	delay(1000);
    Serial.println("start"); 
    pinMode(A5, INPUT_PULLUP);
    FastLED.addLeds<WS2811, DATA_PIN, GRB>(leds, NUM_LEDS);
   
}
void FillLEDsFromPaletteColors( uint8_t colorIndex)
{
    uint8_t brightness = 255;
    
    for( int i = 0; i < NUM_LEDS; ++i) {
        leds[i] = ColorFromPalette( currentPalette, colorIndex, brightness, currentBlending);
        colorIndex += 3;
    }
}

// This function runs over and over, and is where you do the magic to light
// your leds.
void loop() {
  static long buttonTimer = 0;
  static bool buttonPress = false;
  static int lastColorButton = -1;
   // Move a single white led 
   if(lastColorButton != colorButton)
   {
     for(int whiteLed = 0; whiteLed < NUM_LEDS; whiteLed = whiteLed + 1) 
     {
      switch(colorButton)
      {
         case 0: leds[whiteLed] = CRGB::Blue; break;
         case 1: leds[whiteLed] = CRGB::Red; break;
         case 2: currentPalette = RainbowColors_p;
                  currentBlending = LINEARBLEND;
                FillLEDsFromPaletteColors(0);
                break;
      }
   }
    if(digitalRead(A5) == HIGH)
    {
      if(millis() - buttonTimer > 250 && buttonPress == false)
      {
        colorButton++;
        if(colorButton > 2)
          colorButton = 0;

        buttonPress = true;
        Serial.println("Button down");
        
      }
    }
    else
    {
      buttonTimer = millis();
      buttonPress = false;
    }
     
   }
   FastLED.show();

}
